"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDummyTsLs = exports.getCssLs = exports.postcssLs = exports.jsonLs = exports.pugLs = exports.lessLs = exports.scssLs = exports.cssLs = exports.htmlLs = void 0;
const shared_1 = require("@volar/shared");
const fs = require("fs");
const css = require("vscode-css-languageservice");
const html = require("vscode-html-languageservice");
const json = require("vscode-json-languageservice");
const pug = require("vscode-pug-languageservice");
const ts2 = require("vscode-typescript-languageservice");
const schemaRequestService_1 = require("./schemaRequestService");
const fileSystemProvider = {
    stat: (uri) => {
        return new Promise((resolve, reject) => {
            fs.stat(shared_1.uriToFsPath(uri), (err, stats) => {
                if (stats) {
                    resolve({
                        type: stats.isFile() ? html.FileType.File
                            : stats.isDirectory() ? html.FileType.Directory
                                : stats.isSymbolicLink() ? html.FileType.SymbolicLink
                                    : html.FileType.Unknown,
                        ctime: stats.ctimeMs,
                        mtime: stats.mtimeMs,
                        size: stats.size,
                    });
                }
                else {
                    reject(err);
                }
            });
        });
    },
    readDirectory: (uri) => {
        return new Promise((resolve, reject) => {
            fs.readdir(shared_1.uriToFsPath(uri), (err, files) => {
                if (files) {
                    resolve(files.map(file => [file, html.FileType.File]));
                }
                else {
                    reject(err);
                }
            });
        });
    },
};
exports.htmlLs = html.getLanguageService({ fileSystemProvider });
exports.cssLs = css.getCSSLanguageService({ fileSystemProvider });
exports.scssLs = css.getSCSSLanguageService({ fileSystemProvider });
exports.lessLs = css.getLESSLanguageService({ fileSystemProvider });
exports.pugLs = pug.getLanguageService(exports.htmlLs);
exports.jsonLs = json.getLanguageService({ schemaRequestService: schemaRequestService_1.getSchemaRequestService() });
exports.postcssLs = {
    ...exports.scssLs,
    doValidation: (document, stylesheet, documentSettings) => {
        let errors = exports.scssLs.doValidation(document, stylesheet, documentSettings);
        errors = errors.filter(error => error.code !== 'css-semicolonexpected');
        errors = errors.filter(error => error.code !== 'css-ruleorselectorexpected');
        errors = errors.filter(error => error.code !== 'unknownAtRules');
        return errors;
    },
};
function getCssLs(lang) {
    switch (lang) {
        case 'css': return exports.cssLs;
        case 'scss': return exports.scssLs;
        case 'less': return exports.lessLs;
        case 'postcss': return exports.postcssLs;
    }
}
exports.getCssLs = getCssLs;
// Fast dummy TS language service, only has one script.
let dummyTsScriptVersion = 0;
let dummyTsScriptKind = 3;
let dummyTsScript;
let dummyTsLs;
function getDummyTsLs(ts, doc) {
    if (!dummyTsLs) {
        dummyTsLs = ts2.createLanguageService({
            getCompilationSettings: () => ({}),
            getScriptFileNames: () => [shared_1.uriToFsPath(shared_1.fsPathToUri(`dummy.${dummyTsScriptVersion}.ts`))],
            getScriptVersion: () => dummyTsScriptVersion.toString(),
            getScriptSnapshot: () => dummyTsScript,
            getScriptKind: () => dummyTsScriptKind,
            getCurrentDirectory: () => '',
            getDefaultLibFileName: () => '',
        }, ts);
    }
    dummyTsScriptVersion++;
    switch (doc.languageId) {
        case 'javascript':
            dummyTsScriptKind = ts.ScriptKind.JS;
            break;
        case 'typescript':
            dummyTsScriptKind = ts.ScriptKind.TS;
            break;
        case 'javascriptreact':
            dummyTsScriptKind = ts.ScriptKind.JSX;
            break;
        case 'typescriptreact':
            dummyTsScriptKind = ts.ScriptKind.TSX;
            break;
        default:
            dummyTsScriptKind = ts.ScriptKind.TS;
            break;
    }
    dummyTsScript = ts.ScriptSnapshot.fromString(doc.getText());
    return {
        ls: dummyTsLs,
        uri: shared_1.fsPathToUri(`dummy.${dummyTsScriptVersion}.ts`),
    };
}
exports.getDummyTsLs = getDummyTsLs;
//# sourceMappingURL=sharedLs.js.map